@@ -174,7 +174,7 @@ class LastUsedBundle(BaseModel):
 
 class CloudStackPack(BaseModel):
     script = models.TextField(verbose_name=_("Script"),
-                                help_text="Script to init database")
+                                help_text="Script setup database")
     offering = models.ForeignKey('CloudStackOffering', related_name="cs_offering_packs")
     engine_type = models.ForeignKey('physical.EngineType', verbose_name=_("Engine Type"), related_name='cs_packs')
     name = models.CharField(verbose_name=_("Name"),
